<?php
/**
 * Christmas Holiday Theme Customizer
 *
 * @package Christmas Holiday
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function christmas_holiday_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'christmas_holiday_custom_controls' );

function christmas_holiday_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.logo .site-title a',
	 	'render_callback' => 'christmas_holiday_Customize_partial_blogname',
	));

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => 'p.site-description',
		'render_callback' => 'christmas_holiday_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'christmas_holiday_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Homepage Settings', 'christmas-holiday' ),
		'priority' => 10,
	));

	//Topbar
	$wp_customize->add_section( 'christmas_holiday_topbar_section' , array(
    	'title' => __( 'Topbar Section', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_panel_id'
	) );

	$wp_customize->add_setting( 'christmas_holiday_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ));
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_topbar_hide_show',array(
    'label' => esc_html__( 'Show / Hide Topbar','christmas-holiday' ),
    'section' => 'christmas_holiday_topbar_section'
  )));

	$wp_customize->add_setting('christmas_holiday_location_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_location_text',array(
		'label'	=> esc_html__('Location Text','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Park Ave,Portland,USA', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'christmas_holiday_sanitize_number_absint'
	));
	$wp_customize->add_control('christmas_holiday_phone_number',array(
		'label'	=> esc_html__('Phone Number','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '+12 123 456 7890', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_topbar_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_topbar_text',array(
		'label'	=> esc_html__('Add Text','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Christmas Offers', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_topbar_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_topbar_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('christmas_holiday_topbar_link',array(
		'label'	=> esc_html__('Add Link','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'https://example.com/page', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_topbar_section',
		'type'=> 'url'
	));

	//Menus Settings
	$wp_customize->add_section( 'christmas_holiday_menu_section' , array(
    	'title' => __( 'Menus Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_panel_id'
	) );

	$wp_customize->add_setting('christmas_holiday_navigation_menu_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_navigation_menu_font_size',array(
		'label'	=> __('Menus Font Size','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_menu_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_navigation_menu_font_weight',array(
        'default' => 500,
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_navigation_menu_font_weight',array(
        'type' => 'select',
        'label' => __('Menus Font Weight','christmas-holiday'),
        'section' => 'christmas_holiday_menu_section',
        'choices' => array(
        	'100' => __('100','christmas-holiday'),
            '200' => __('200','christmas-holiday'),
            '300' => __('300','christmas-holiday'),
            '400' => __('400','christmas-holiday'),
            '500' => __('500','christmas-holiday'),
            '600' => __('600','christmas-holiday'),
            '700' => __('700','christmas-holiday'),
            '800' => __('800','christmas-holiday'),
            '900' => __('900','christmas-holiday'),
        ),
	) );

	// text trasform
	$wp_customize->add_setting('christmas_holiday_menu_text_transform',array(
		'default'=> 'Capitalize',
		'sanitize_callback'	=> 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_menu_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Menus Text Transform','christmas-holiday'),
		'choices' => array(
            'Uppercase' => __('Uppercase','christmas-holiday'),
            'Capitalize' => __('Capitalize','christmas-holiday'),
            'Lowercase' => __('Lowercase','christmas-holiday'),
        ),
		'section'=> 'christmas_holiday_menu_section',
	));

	$wp_customize->add_setting('christmas_holiday_menus_item_style',array(
        'default' => '',
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_menus_item_style',array(
				'type' => 'select',
				'section' => 'christmas_holiday_menu_section',
				'label' => __('Menu Item Hover Style','christmas-holiday'),
				'choices' => array(
				  'None' => __('None','christmas-holiday'),
				  'Zoom In' => __('Zoom In','christmas-holiday'),
        ),
	) );

	$wp_customize->add_setting('christmas_holiday_header_menus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_header_menus_color', array(
		'label'    => __('Menus Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_menu_section',
	)));

	$wp_customize->add_setting('christmas_holiday_header_menus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_header_menus_hover_color', array(
		'label'    => __('Menus Hover Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_menu_section',
	)));

	$wp_customize->add_setting('christmas_holiday_header_submenus_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_header_submenus_color', array(
		'label'    => __('Sub Menus Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_menu_section',
	)));

	$wp_customize->add_setting('christmas_holiday_header_submenus_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_header_submenus_hover_color', array(
		'label'    => __('Sub Menus Hover Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_menu_section',
	)));

	//Slider
	$wp_customize->add_section( 'christmas_holiday_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'christmas-holiday' ),
    	'description' => __('Free theme has 3 slides options, For unlimited slides and more options </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/christmas-holiday-wordpress-theme/">GO PRO</a>','christmas-holiday'),
		'panel' => 'christmas_holiday_panel_id'
	) );

	$wp_customize->add_setting( 'christmas_holiday_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ));
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','christmas-holiday' ),
      'section' => 'christmas_holiday_slidersettings'
    )));

     $wp_customize->add_setting('christmas_holiday_slider_type',array(
        'default' => 'Default slider',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	) );
	$wp_customize->add_control('christmas_holiday_slider_type', array(
        'type' => 'select',
        'label' => __('Slider Type','christmas-holiday'),
        'section' => 'christmas_holiday_slidersettings',
        'choices' => array(
            'Default slider' => __('Default slider','christmas-holiday'),
            'Advance slider' => __('Advance slider','christmas-holiday'),
        ),
	));

	$wp_customize->add_setting('christmas_holiday_advance_slider_shortcode',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_advance_slider_shortcode',array(
		'label'	=> __('Add Slider Shortcode','christmas-holiday'),
		'section'=> 'christmas_holiday_slidersettings',
		'type'=> 'text',
		'active_callback' => 'christmas_holiday_advance_slider'
	));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('christmas_holiday_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'christmas_holiday_customize_partial_christmas_holiday_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'christmas_holiday_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'christmas_holiday_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'christmas_holiday_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'christmas-holiday' ),
			'description' => __('Slider image size (1400 x 550)','christmas-holiday'),
			'section'  => 'christmas_holiday_slidersettings',
			'type'     => 'dropdown-pages',
			'active_callback' => 'christmas_holiday_default_slider'
		) );
	}

	$wp_customize->add_setting( 'christmas_holiday_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'christmas_holiday_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','christmas-holiday'),
		'section' => 'christmas_holiday_slidersettings',
		'type'  => 'text',
		'active_callback' => 'christmas_holiday_default_slider'
	) );

	//Slider height
	$wp_customize->add_setting('christmas_holiday_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_slider_height',array(
		'label'	=> __('Slider Height','christmas-holiday'),
		'description'	=> __('Specify the slider height (px).','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_slidersettings',
		'type'=> 'text',
		'active_callback' => 'christmas_holiday_default_slider'
	));

	//Opacity
	$wp_customize->add_setting('christmas_holiday_slider_opacity_color',array(
      'default'              => 0.7,
      'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));

	$wp_customize->add_control( 'christmas_holiday_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','christmas-holiday' ),
		'section'     => 'christmas_holiday_slidersettings',
		'type'        => 'select',
		'settings'    => 'christmas_holiday_slider_opacity_color',
		'choices' => array(
	      '0' =>  esc_attr('0','christmas-holiday'),
	      '0.1' =>  esc_attr('0.1','christmas-holiday'),
	      '0.2' =>  esc_attr('0.2','christmas-holiday'),
	      '0.3' =>  esc_attr('0.3','christmas-holiday'),
	      '0.4' =>  esc_attr('0.4','christmas-holiday'),
	      '0.5' =>  esc_attr('0.5','christmas-holiday'),
	      '0.6' =>  esc_attr('0.6','christmas-holiday'),
	      '0.7' =>  esc_attr('0.7','christmas-holiday'),
	      '0.8' =>  esc_attr('0.8','christmas-holiday'),
	      '0.9' =>  esc_attr('0.9','christmas-holiday')
	),'active_callback' => 'christmas_holiday_default_slider'
	));

	//Feature Section
	$wp_customize->add_section('christmas_holiday_feature', array(
		'title'       => __('Feature Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_feature_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_feature_text',array(
		'description' => __('<p>1. More options for feature section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for feature section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_feature',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_feature_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_feature_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_feature',
		'type'=> 'hidden'
	));

	//Sale Section
	$wp_customize->add_section('christmas_holiday_sale', array(
		'title'       => __('Sale Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_sale_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_sale_text',array(
		'description' => __('<p>1. More options for sale section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for sale section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_sale',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_sale_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_sale_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_sale',
		'type'=> 'hidden'
	));

	//Offer Section
	$wp_customize->add_section('christmas_holiday_offer', array(
		'title'       => __('Offer Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_offer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_offer_text',array(
		'description' => __('<p>1. More options for offer section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for offer section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_offer',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_offer_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_offer_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_offer',
		'type'=> 'hidden'
	));

	//New Product Section
	$wp_customize->add_section('christmas_holiday_new_product', array(
		'title'       => __('New Product Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_new_product_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_new_product_text',array(
		'description' => __('<p>1. More options for new product section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for new product section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_new_product',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_new_product_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_new_product_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_new_product',
		'type'=> 'hidden'
	));

	//Feature Product Section
	$wp_customize->add_section('christmas_holiday_feature_product', array(
		'title'       => __('Feature Product Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_feature_product_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_feature_product_text',array(
		'description' => __('<p>1. More options for feature product section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for feature product section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_feature_product',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_feature_product_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_feature_product_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_feature_product',
		'type'=> 'hidden'
	));

	//Best Seller Products Section
	$wp_customize->add_section('christmas_holiday_best_seller_products_section',array(
		'title'	=> __('Best Seller Products Section','christmas-holiday'),
		'description' => __('For more options of Best Seller Products section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/christmas-holiday-wordpress-theme/">GO PRO</a>','christmas-holiday'),
		'panel' => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting( 'christmas_holiday_bestseller_banner_page' , array(
		'default'           => '',
		'sanitize_callback' => 'christmas_holiday_sanitize_dropdown_pages'
	));
	$wp_customize->add_control( 'christmas_holiday_bestseller_banner_page' , array(
		'label'    => __( 'Select Banner Page', 'christmas-holiday' ),
		'description' => __('Product Image size (285 x 345)','christmas-holiday'),
		'section'  => 'christmas_holiday_best_seller_products_section',
		'type'     => 'dropdown-pages'
	) );

	$args = array(
		'type'         => 'product',
		'child_of'     => 0,
		'parent'       => '',
		'orderby'      => 'term_group',
		'order'        => 'ASC',
		'hide_empty'   => false,
		'hierarchical' => 1,
		'number'       => '',
		'taxonomy'     => 'product_cat',
		'pad_counts'   => false
	);
 	$categories = get_categories( $args );
	$cat_posts = array();
	$i = 0;
	$cat_posts[]='Select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name; 
	}

	$wp_customize->add_setting('christmas_holiday_sale_product_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'christmas_holiday_sanitize_choices',
	));
	$wp_customize->add_control('christmas_holiday_sale_product_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Sale Products','christmas-holiday'),
		'description' => __('Product Image size (300 x 300)','christmas-holiday'),
		'section' => 'christmas_holiday_best_seller_products_section',
	));

	$wp_customize->add_setting('christmas_holiday_product_timer_text',array(
		'default'=> '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('christmas_holiday_product_timer_text',array(
		'label' => __('Timer Text','christmas-holiday'),
		'section' => 'christmas_holiday_best_seller_products_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_product_clock_timer_end',array(
		'default'=> '',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('christmas_holiday_product_clock_timer_end',array(
		'label' => __('Enter End Date of Timer','christmas-holiday'),
		'section' => 'christmas_holiday_best_seller_products_section',
		'description' => __('Timer get the current date and time. So you just need to add the end date. Please Use the following format to add the date "Month date year hours:minutes:seconds" example "April 11 2022 11:00:00".','christmas-holiday'),
		'type'=> 'text'
	));

	//testimonials Section
	$wp_customize->add_section('christmas_holiday_testimonials', array(
		'title'       => __('Testimonials Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_testimonials_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_testimonials_text',array(
		'description' => __('<p>1. More options for testimonials section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for testimonials section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_testimonials',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_testimonials_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_testimonials_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_testimonials',
		'type'=> 'hidden'
	));

	//Latest Post Section
	$wp_customize->add_section('christmas_holiday_latest_post', array(
		'title'       => __('Latest Post Section', 'christmas-holiday'),
		'description' => __('<p class="premium-opt">Premium Theme Features</p>','christmas-holiday'),
		'priority'    => null,
		'panel'       => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_latest_post_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_latest_post_text',array(
		'description' => __('<p>1. More options for latest post section.</p>
			<p>2. Unlimited images options.</p>
			<p>3. Color options for latest post section.</p>','christmas-holiday'),
		'section'=> 'christmas_holiday_latest_post',
		'type'=> 'hidden'
	));

	$wp_customize->add_setting('christmas_holiday_latest_post_btn',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_latest_post_btn',array(
		'description' => "<a class='go-pro' target='_blank' href='". admin_url('themes.php?page=christmas_holiday_guide') ." '>More Info</a>",
		'section'=> 'christmas_holiday_latest_post',
		'type'=> 'hidden'
	));

	//Footer Text
	$wp_customize->add_section('christmas_holiday_footer',array(
		'title'	=> esc_html__('Footer Settings','christmas-holiday'),
		'description' => __('For more options of footer section </br> <a class="go-pro-btn" target="blank" href="https://www.vwthemes.com/themes/christmas-holiday-wordpress-theme/">GO PRO</a>','christmas-holiday'),
		'panel' => 'christmas_holiday_panel_id',
	));

	$wp_customize->add_setting('christmas_holiday_footer_background_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_footer_background_color', array(
		'label'    => __('Footer Background Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_footer',
	)));

	$wp_customize->add_setting('christmas_holiday_footer_background_image',array(
		'default'	=> '',
		'sanitize_callback'	=> 'esc_url_raw',
	));
	$wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'christmas_holiday_footer_background_image',array(
        'label' => __('Footer Background Image','christmas-holiday'),
        'section' => 'christmas_holiday_footer'
	)));

	// Footer
	$wp_customize->add_setting('christmas_holiday_img_footer',array(
		'default'=> 'scroll',
		'sanitize_callback'	=> 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_img_footer',array(
		'type' => 'select',
		'label'	=> __('Footer Background Attatchment','christmas-holiday'),
		'choices' => array(
            'fixed' => __('fixed','christmas-holiday'),
            'scroll' => __('scroll','christmas-holiday'),
        ),
		'section'=> 'christmas_holiday_footer',
	));

	$wp_customize->add_setting('christmas_holiday_footer_widgets_heading',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_footer_widgets_heading',array(
        'type' => 'select',
        'label' => __('Footer Widget Heading','christmas-holiday'),
        'section' => 'christmas_holiday_footer',
        'choices' => array(
        	'Left' => __('Left','christmas-holiday'),
            'Center' => __('Center','christmas-holiday'),
            'Right' => __('Right','christmas-holiday')
        ),
	) );

	$wp_customize->add_setting('christmas_holiday_footer_widgets_content',array(
        'default' => 'Left',
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_footer_widgets_content',array(
        'type' => 'select',
        'label' => __('Footer Widget Content','christmas-holiday'),
        'section' => 'christmas_holiday_footer',
        'choices' => array(
        	'Left' => __('Left','christmas-holiday'),
            'Center' => __('Center','christmas-holiday'),
            'Right' => __('Right','christmas-holiday')
        ),
	) );

	// footer padding
	$wp_customize->add_setting('christmas_holiday_footer_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_footer_padding',array(
		'label'	=> __('Footer Top Bottom Padding','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'christmas-holiday' ),
    ),
		'section'=> 'christmas_holiday_footer',
		'type'=> 'text'
	));

   // footer social icon
	$wp_customize->add_setting( 'christmas_holiday_footer_icon',array(
		'default' => false,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
	$wp_customize->add_control( new christmas_holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_footer_icon',array(
		'label' => esc_html__( 'Footer Social Icon','christmas-holiday' ),
		'section' => 'christmas_holiday_footer'
  )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('christmas_holiday_footer_text', array(
		'selector' => '.copyright p',
		'render_callback' => 'christmas_holiday_Customize_partial_christmas_holiday_footer_text',
	));

	$wp_customize->add_setting('christmas_holiday_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_footer_text',array(
		'label'	=> esc_html__('Copyright Text','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2021, .....', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control(new Christmas_Holiday_Image_Radio_Control($wp_customize, 'christmas_holiday_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','christmas-holiday'),
        'section' => 'christmas_holiday_footer',
        'settings' => 'christmas_holiday_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

  $wp_customize->add_setting( 'christmas_holiday_hide_show_scroll',array(
  	'default' => 1,
    	'transport' => 'refresh',
    	'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ));
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','christmas-holiday' ),
      	'section' => 'christmas_holiday_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('christmas_holiday_scroll_to_top_icon', array(
		'selector' => '.scrollup i',
		'render_callback' => 'christmas_holiday_Customize_partial_christmas_holiday_scroll_to_top_icon',
	));

    $wp_customize->add_setting('christmas_holiday_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control(new Christmas_Holiday_Image_Radio_Control($wp_customize, 'christmas_holiday_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','christmas-holiday'),
        'section' => 'christmas_holiday_footer',
        'settings' => 'christmas_holiday_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));

	//Blog Post
	$wp_customize->add_panel( 'christmas_holiday_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_panel_id',
		'priority' => 10,
	));

	//Blog layout
    $wp_customize->add_setting('christmas_holiday_blog_layout_option',array(
      'default' => 'Default',
      'sanitize_callback' => 'christmas_holiday_sanitize_choices'
    ));
    $wp_customize->add_control(new christmas_holiday_Image_Radio_Control($wp_customize, 'christmas_holiday_blog_layout_option', array(
      'type' => 'select',
      'label' => __('Blog Post Layouts','christmas-holiday'),
      'section' => 'christmas_holiday_post_settings',
      'choices' => array(
          'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
          'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
          'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'christmas_holiday_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('christmas_holiday_toggle_postdate', array(
		'selector' => '.post-main-box h2 a',
		'render_callback' => 'christmas_holiday_Customize_partial_christmas_holiday_toggle_postdate',
	));

  $wp_customize->add_setting('christmas_holiday_toggle_postdate_icon',array(
		'default'	=> 'fas fa-calendar-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Christmas_Holiday_Fontawesome_Icon_Chooser(
        $wp_customize,'christmas_holiday_toggle_postdate_icon',array(
		'label'	=> __('Add Post Date Icon','christmas-holiday'),
		'transport' => 'refresh',
		'section'	=> 'christmas_holiday_post_settings',
		'setting'	=> 'christmas_holiday_toggle_postdate_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting( 'christmas_holiday_toggle_postdate',array(
    'default' => 1,
    'transport' => 'refresh',
    'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_postdate',array(
    'label' => esc_html__( 'Post Date','christmas-holiday' ),
    'section' => 'christmas_holiday_post_settings'
  )));

	$wp_customize->add_setting('christmas_holiday_toggle_author_icon',array(
		'default'	=> 'fas fa-user',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Christmas_Holiday_Fontawesome_Icon_Chooser(
        $wp_customize,'christmas_holiday_toggle_author_icon',array(
		'label'	=> __('Add Author Icon','christmas-holiday'),
		'transport' => 'refresh',
		'section'	=> 'christmas_holiday_post_settings',
		'setting'	=> 'christmas_holiday_toggle_author_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'christmas_holiday_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_author',array(
		'label' => esc_html__( 'Author','christmas-holiday' ),
		'section' => 'christmas_holiday_post_settings'
  )));

  $wp_customize->add_setting('christmas_holiday_toggle_comments_icon',array(
		'default'	=> 'fa fa-comments',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Christmas_Holiday_Fontawesome_Icon_Chooser(
        $wp_customize,'christmas_holiday_toggle_comments_icon',array(
		'label'	=> __('Add Comments Icon','christmas-holiday'),
		'transport' => 'refresh',
		'section'	=> 'christmas_holiday_post_settings',
		'setting'	=> 'christmas_holiday_toggle_comments_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'christmas_holiday_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_comments',array(
		'label' => esc_html__( 'Comments','christmas-holiday' ),
		'section' => 'christmas_holiday_post_settings'
  )));

  $wp_customize->add_setting('christmas_holiday_toggle_time_icon',array(
		'default'	=> 'fas fa-clock',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control(new Christmas_Holiday_Fontawesome_Icon_Chooser(
  $wp_customize,'christmas_holiday_toggle_time_icon',array(
		'label'	=> __('Add Time Icon','christmas-holiday'),
		'transport' => 'refresh',
		'section'	=> 'christmas_holiday_post_settings',
		'setting'	=> 'christmas_holiday_toggle_time_icon',
		'type'		=> 'icon'
	)));

  $wp_customize->add_setting( 'christmas_holiday_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_time',array(
		'label' => esc_html__( 'Time','christmas-holiday' ),
		'section' => 'christmas_holiday_post_settings'
  )));

  $wp_customize->add_setting( 'christmas_holiday_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	));
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_tags', array(
		'label' => esc_html__( 'Tags','christmas-holiday' ),
		'section' => 'christmas_holiday_post_settings'
    )));

  $wp_customize->add_setting( 'christmas_holiday_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	));
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','christmas-holiday' ),
		'section' => 'christmas_holiday_post_settings'
  )));

  $wp_customize->add_setting( 'christmas_holiday_featured_image_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'christmas_holiday_sanitize_number_range'
	) );
	$wp_customize->add_control( 'christmas_holiday_featured_image_border_radius', array(
		'label'       => esc_html__( 'Featured Image Border Radius','christmas-holiday' ),
		'section'     => 'christmas_holiday_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'christmas_holiday_featured_image_box_shadow', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'christmas_holiday_sanitize_number_range'
	) );
	$wp_customize->add_control( 'christmas_holiday_featured_image_box_shadow', array(
		'label'       => esc_html__( 'Featured Image Box Shadow','christmas-holiday' ),
		'section'     => 'christmas_holiday_post_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Featured Image
	$wp_customize->add_setting('christmas_holiday_blog_post_featured_image_dimension',array(
	       'default' => 'default',
	       'sanitize_callback'	=> 'christmas_holiday_sanitize_choices'
	));
  	$wp_customize->add_control('christmas_holiday_blog_post_featured_image_dimension',array(
	     'type' => 'select',
	     'label'	=> __('Blog Post Featured Image Dimension','christmas-holiday'),
	     'section'	=> 'christmas_holiday_post_settings',
	     'choices' => array(
          'default' => __('Default','christmas-holiday'),
          'custom' => __('Custom Image Size','christmas-holiday'),
      ),
  	));

	$wp_customize->add_setting('christmas_holiday_blog_post_featured_image_custom_width',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
	$wp_customize->add_control('christmas_holiday_blog_post_featured_image_custom_width',array(
			'label'	=> __('Featured Image Custom Width','christmas-holiday'),
			'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
			'input_attrs' => array(
	    	'placeholder' => __( '10px', 'christmas-holiday' ),),
			'section'=> 'christmas_holiday_post_settings',
			'type'=> 'text',
			'active_callback' => 'christmas_holiday_blog_post_featured_image_dimension'
		));

	$wp_customize->add_setting('christmas_holiday_blog_post_featured_image_custom_height',array(
			'default'=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_blog_post_featured_image_custom_height',array(
			'label'	=> __('Featured Image Custom Height','christmas-holiday'),
			'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
			'input_attrs' => array(
	    	'placeholder' => __( '10px', 'christmas-holiday' ),),
			'section'=> 'christmas_holiday_post_settings',
			'type'=> 'text',
			'active_callback' => 'christmas_holiday_blog_post_featured_image_dimension'
	));

  $wp_customize->add_setting( 'christmas_holiday_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'christmas_holiday_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'christmas_holiday_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','christmas-holiday' ),
		'section'     => 'christmas_holiday_post_settings',
		'type'        => 'range',
		'settings'    => 'christmas_holiday_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('christmas_holiday_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','christmas-holiday'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','christmas-holiday'),
		'section'=> 'christmas_holiday_post_settings',
		'type'=> 'text'
	));

  $wp_customize->add_setting('christmas_holiday_excerpt_settings',array(
    'default' => 'Excerpt',
    'transport' => 'refresh',
    'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_excerpt_settings',array(
    'type' => 'select',
    'label' => esc_html__('Post Content','christmas-holiday'),
    'section' => 'christmas_holiday_post_settings',
    'choices' => array(
    	'Content' => esc_html__('Content','christmas-holiday'),
        'Excerpt' => esc_html__('Excerpt','christmas-holiday'),
        'No Content' => esc_html__('No Content','christmas-holiday')
        ),
	) );

  $wp_customize->add_setting('christmas_holiday_blog_page_posts_settings',array(
    'default' => 'Into Blocks',
    'transport' => 'refresh',
    'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_blog_page_posts_settings',array(
    'type' => 'select',
    'label' => __('Display Blog Page posts','christmas-holiday'),
    'section' => 'christmas_holiday_post_settings',
    'choices' => array(
    	'Into Blocks' => __('Into Blocks','christmas-holiday'),
        'Without Blocks' => __('Without Blocks','christmas-holiday')
        ),
	) );

  // Button Settings
	$wp_customize->add_section( 'christmas_holiday_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('christmas_holiday_button_text', array(
		'selector' => '.post-main-box .more-btn a',
		'render_callback' => 'christmas_holiday_Customize_partial_christmas_holiday_button_text',
	));

    $wp_customize->add_setting('christmas_holiday_button_text',array(
		'default'=> esc_html__('Read More','christmas-holiday'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_button_text',array(
		'label'	=> esc_html__('Add Button Text','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_button_settings',
		'type'=> 'text'
	));

	// font size button
	$wp_customize->add_setting('christmas_holiday_button_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_button_font_size',array(
		'label'	=> __('Button Font Size','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
      'placeholder' => __( '10px', 'christmas-holiday' ),
    ),
    'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'christmas_holiday_button_settings',
	));

	$wp_customize->add_setting( 'christmas_holiday_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'christmas_holiday_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'christmas_holiday_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','christmas-holiday' ),
		'section'     => 'christmas_holiday_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('christmas_holiday_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('christmas_holiday_button_letter_spacing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_button_letter_spacing',array(
		'label'	=> __('Button Letter Spacing','christmas-holiday'),
		'description'	=> __('Enter a value in pixels. Example:20px','christmas-holiday'),
		'input_attrs' => array(
      	'placeholder' => __( '10px', 'christmas-holiday' ),
    ),
    	'type'        => 'text',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
		'section'=> 'christmas_holiday_button_settings',
	));

	// text trasform
	$wp_customize->add_setting('christmas_holiday_button_text_transform',array(
		'default'=> 'Uppercase',
		'sanitize_callback'	=> 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_button_text_transform',array(
		'type' => 'radio',
		'label'	=> __('Button Text Transform','christmas-holiday'),
		'choices' => array(
            'Uppercase' => __('Uppercase','christmas-holiday'),
            'Capitalize' => __('Capitalize','christmas-holiday'),
            'Lowercase' => __('Lowercase','christmas-holiday'),
        ),
		'section'=> 'christmas_holiday_button_settings',
	));

	// Related Post Settings
	$wp_customize->add_section( 'christmas_holiday_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('christmas_holiday_related_post_title', array(
		'selector' => '.related-post h3',
		'render_callback' => 'christmas_holiday_Customize_partial_christmas_holiday_related_post_title',
	));

    $wp_customize->add_setting( 'christmas_holiday_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ) );
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_related_post',array(
		'label' => esc_html__( 'Related Post','christmas-holiday' ),
		'section' => 'christmas_holiday_related_posts_settings'
    )));

    $wp_customize->add_setting('christmas_holiday_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('christmas_holiday_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'christmas_holiday_sanitize_number_absint'
	));
	$wp_customize->add_control('christmas_holiday_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_related_posts_settings',
		'type'=> 'number'
	));

	$wp_customize->add_setting( 'christmas_holiday_related_posts_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'christmas_holiday_sanitize_number_range'
	) );
	$wp_customize->add_control( 'christmas_holiday_related_posts_excerpt_number', array(
		'label'       => esc_html__( 'Related Posts Excerpt length','christmas-holiday' ),
		'section'     => 'christmas_holiday_related_posts_settings',
		'type'        => 'range',
		'settings'    => 'christmas_holiday_related_posts_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Single Post Settings
	$wp_customize->add_section( 'christmas_holiday_single_post_settings', array(
		'title' => esc_html__( 'Single Post Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'christmas_holiday_single_postdate',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	) );
	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_postdate',array(
	    'label' => esc_html__( 'Date','christmas-holiday' ),
	   'section' => 'christmas_holiday_single_post_settings'
	)));

    $wp_customize->add_setting( 'christmas_holiday_single_author',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	) );
	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_author',array(
	    'label' => esc_html__( 'Author','christmas-holiday' ),
	    'section' => 'christmas_holiday_single_post_settings'
	)));

	$wp_customize->add_setting( 'christmas_holiday_single_comments',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	) );
	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_comments',array(
	    'label' => esc_html__( 'Comments','christmas-holiday' ),
	    'section' => 'christmas_holiday_single_post_settings'
	)));

	$wp_customize->add_setting( 'christmas_holiday_single_time',array(
	    'default' => 1,
	    'transport' => 'refresh',
	    'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	) );

	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_time',array(
	    'label' => esc_html__( 'Time','christmas-holiday' ),
	    'section' => 'christmas_holiday_single_post_settings'
	)));

	$wp_customize->add_setting( 'christmas_holiday_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	));
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_toggle_tags', array(
		'label' => esc_html__( 'Tags','christmas-holiday' ),
		'section' => 'christmas_holiday_single_post_settings'
  )));

	$wp_customize->add_setting( 'christmas_holiday_single_post_breadcrumb',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ) );
 	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_post_breadcrumb',array(
	'label' => esc_html__( 'Single Post Breadcrumb','christmas-holiday' ),
	'section' => 'christmas_holiday_single_post_settings'
  )));

   // Single Posts Category
	$wp_customize->add_setting( 'christmas_holiday_single_post_category',array(
		'default' => true,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_post_category',array(
		'label' => esc_html__( 'Single Post Category','christmas-holiday' ),
		'section' => 'christmas_holiday_single_post_settings'
  )));

 	$wp_customize->add_setting( 'christmas_holiday_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
	));
	$wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_blog_post_navigation_show_hide', array(
		  'label' => esc_html__( 'Post Navigation','christmas-holiday' ),
		  'section' => 'christmas_holiday_single_post_settings'
	)));

	$wp_customize->add_setting('christmas_holiday_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','christmas-holiday'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','christmas-holiday'),
		'section'=> 'christmas_holiday_single_post_settings',
		'type'=> 'text'
	));

   $wp_customize->add_setting('christmas_holiday_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('christmas_holiday_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','christmas-holiday'),
		'description'	=> __('Enter a value in %. Example:50%','christmas-holiday'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'christmas-holiday' ),
        ),
		'section'=> 'christmas_holiday_single_post_settings',
		'type'=> 'text'
	));

	  // Grid layout setting
	$wp_customize->add_section( 'christmas_holiday_grid_layout_settings', array(
		'title' => __( 'Grid Layout Settings', 'christmas-holiday' ),
		'panel' => 'christmas_holiday_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'christmas_holiday_grid_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_grid_postdate',array(
      'label' => esc_html__( 'Post Date','christmas-holiday' ),
      'section' => 'christmas_holiday_grid_layout_settings'
  )));

  $wp_customize->add_setting( 'christmas_holiday_grid_author',array(
	'default' => 1,
	'transport' => 'refresh',
	'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_grid_author',array(
	'label' => esc_html__( 'Author','christmas-holiday' ),
	'section' => 'christmas_holiday_grid_layout_settings'
  )));

  $wp_customize->add_setting( 'christmas_holiday_grid_comments',array(
	'default' => 1,
	'transport' => 'refresh',
	'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_grid_comments',array(
	'label' => esc_html__( 'Comments','christmas-holiday' ),
	'section' => 'christmas_holiday_grid_layout_settings'
  )));

   // Other Setting
	$wp_customize->add_panel( 'christmas_holiday_other_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'Other Settings', 'christmas-holiday' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'christmas_holiday_left_right', array(
    	'title' => esc_html__('General Settings', 'christmas-holiday'),
		'panel' => 'christmas_holiday_other_panel_id'
	) );

	$wp_customize->add_setting('christmas_holiday_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control(new Christmas_Holiday_Image_Radio_Control($wp_customize, 'christmas_holiday_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','christmas-holiday'),
        'description' => esc_html__('Here you can change the width layout of Website.','christmas-holiday'),
        'section' => 'christmas_holiday_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('christmas_holiday_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','christmas-holiday'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','christmas-holiday'),
        'section' => 'christmas_holiday_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','christmas-holiday'),
            'Right Sidebar' => esc_html__('Right Sidebar','christmas-holiday'),
            'One Column' => esc_html__('One Column','christmas-holiday'),
            'Grid Layout' => esc_html__('Grid Layout','christmas-holiday')
        ),
	) );

	$wp_customize->add_setting('christmas_holiday_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','christmas-holiday'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','christmas-holiday'),
        'section' => 'christmas_holiday_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','christmas-holiday'),
            'Right_Sidebar' => esc_html__('Right Sidebar','christmas-holiday'),
            'One_Column' => esc_html__('One Column','christmas-holiday')
        ),
	) );

  $wp_customize->add_setting( 'christmas_holiday_single_page_breadcrumb',array(
	'default' => 1,
	'transport' => 'refresh',
	'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_single_page_breadcrumb',array(
	'label' => esc_html__( 'Single Page Breadcrumb','christmas-holiday' ),
	'section' => 'christmas_holiday_left_right'
  )));

    // Pre-Loader
	$wp_customize->add_setting( 'christmas_holiday_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ) );
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','christmas-holiday' ),
        'section' => 'christmas_holiday_left_right'
    )));

	$wp_customize->add_setting('christmas_holiday_preloader_bg_color', array(
		'default'           => '#F82938',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_left_right',
	)));

	$wp_customize->add_setting('christmas_holiday_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_left_right',
	)));


	//Responsive Media Settings
	$wp_customize->add_section('christmas_holiday_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','christmas-holiday'),
		'panel' => 'christmas_holiday_other_panel_id',
	));

    $wp_customize->add_setting( 'christmas_holiday_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ));
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','christmas-holiday' ),
      	'section' => 'christmas_holiday_responsive_media'
    )));

    $wp_customize->add_setting( 'christmas_holiday_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ));
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','christmas-holiday' ),
      	'section' => 'christmas_holiday_responsive_media'
    )));

    $wp_customize->add_setting( 'christmas_holiday_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
    ));
    $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','christmas-holiday' ),
      	'section' => 'christmas_holiday_responsive_media'
    )));

    $wp_customize->add_setting('christmas_holiday_resp_menu_toggle_btn_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'christmas_holiday_resp_menu_toggle_btn_bg_color', array(
		'label'    => __('Toggle Button Bg Color', 'christmas-holiday'),
		'section'  => 'christmas_holiday_responsive_media',
	)));

    //Woocommerce settings
	$wp_customize->add_section('christmas_holiday_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'christmas-holiday'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'christmas_holiday_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar',
		'render_callback' => 'christmas_holiday_customize_partial_christmas_holiday_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'christmas_holiday_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','christmas-holiday' ),
		'section' => 'christmas_holiday_woocommerce_section'
  )));

  $wp_customize->add_setting('christmas_holiday_shop_page_layout',array(
    'default' => 'Right Sidebar',
    'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_shop_page_layout',array(
    'type' => 'select',
    'label' => __('Shop Page Sidebar Layout','christmas-holiday'),
    'section' => 'christmas_holiday_woocommerce_section',
    'choices' => array(
        'Left Sidebar' => __('Left Sidebar','christmas-holiday'),
        'Right Sidebar' => __('Right Sidebar','christmas-holiday'),
        ),
	) );

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'christmas_holiday_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar',
		'render_callback' => 'christmas_holiday_customize_partial_christmas_holiday_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'christmas_holiday_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
	 $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','christmas-holiday' ),
		'section' => 'christmas_holiday_woocommerce_section'
  )));

  $wp_customize->add_setting('christmas_holiday_single_product_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'christmas_holiday_sanitize_choices'
	));
	$wp_customize->add_control('christmas_holiday_single_product_layout',array(
        'type' => 'select',
        'label' => __('Single Product Sidebar Layout','christmas-holiday'),
        'section' => 'christmas_holiday_woocommerce_section',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','christmas-holiday'),
            'Right Sidebar' => __('Right Sidebar','christmas-holiday'),
        ),
	) );

  // Related Product
  $wp_customize->add_setting( 'christmas_holiday_related_product_show_hide',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'christmas_holiday_switch_sanitization'
  ) );
  $wp_customize->add_control( new Christmas_Holiday_Toggle_Switch_Custom_Control( $wp_customize, 'christmas_holiday_related_product_show_hide',array(
      'label' => esc_html__( 'Related product','christmas-holiday' ),
      'section' => 'christmas_holiday_woocommerce_section'
  )));


}

add_action( 'customize_register', 'christmas_holiday_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Christmas_Holiday_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Christmas_Holiday_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Christmas_Holiday_Customize_Section_Pro( $manager,'christmas_holiday_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'CHRISTMAS PRO', 'christmas-holiday' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'christmas-holiday' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/christmas-holiday-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Christmas_Holiday_Customize_Section_Pro($manager,'christmas_holiday_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'christmas-holiday' ),
			'pro_text' => esc_html__( 'DOCS', 'christmas-holiday' ),
			'pro_url'  => esc_url('https://www.vwthemesdemo.com/docs/free-christmas-holiday/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'christmas-holiday-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'christmas-holiday-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Christmas_Holiday_Customize::get_instance();
